==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/MATERIALLISTPARTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour MATERIALLISTPARTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="MATERIALLISTPARTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTPARTLINENUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MATERIALLISTPARTID_Type", propOrder = {
    "materiallistid",
    "materiallistpartlinenum"
})
public class MATERIALLISTPARTID_Type {

    @XmlElement(name = "MATERIALLISTID", required = true)
    protected MATERIALLISTID_Type materiallistid;
    @XmlElement(name = "MATERIALLISTPARTLINENUM")
    protected long materiallistpartlinenum;

    /**
     * Obtient la valeur de la propriété materiallistid.
     * 
     * @return
     *     possible object is
     *     {@link MATERIALLISTID_Type }
     *     
     */
    public MATERIALLISTID_Type getMATERIALLISTID() {
        return materiallistid;
    }

    /**
     * Définit la valeur de la propriété materiallistid.
     * 
     * @param value
     *     allowed object is
     *     {@link MATERIALLISTID_Type }
     *     
     */
    public void setMATERIALLISTID(MATERIALLISTID_Type value) {
        this.materiallistid = value;
    }

    /**
     * Obtient la valeur de la propriété materiallistpartlinenum.
     * 
     */
    public long getMATERIALLISTPARTLINENUM() {
        return materiallistpartlinenum;
    }

    /**
     * Définit la valeur de la propriété materiallistpartlinenum.
     * 
     */
    public void setMATERIALLISTPARTLINENUM(long value) {
        this.materiallistpartlinenum = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/MATERIALLISTPARTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MATERIALLISTPARTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="MATERIALLISTPARTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTPARTLINENUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MATERIALLISTPARTID_Type", propOrder = {
    "materiallistid",
    "materiallistpartlinenum"
})
public class MATERIALLISTPARTID_Type {

    @XmlElement(name = "MATERIALLISTID", required = true)
    protected MATERIALLISTID_Type materiallistid;
    @XmlElement(name = "MATERIALLISTPARTLINENUM")
    protected long materiallistpartlinenum;

    /**
     * Gets the value of the materiallistid property.
     * 
     * @return
     *     possible object is
     *     {@link MATERIALLISTID_Type }
     *     
     */
    public MATERIALLISTID_Type getMATERIALLISTID() {
        return materiallistid;
    }

    /**
     * Sets the value of the materiallistid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MATERIALLISTID_Type }
     *     
     */
    public void setMATERIALLISTID(MATERIALLISTID_Type value) {
        this.materiallistid = value;
    }

    /**
     * Gets the value of the materiallistpartlinenum property.
     * 
     */
    public long getMATERIALLISTPARTLINENUM() {
        return materiallistpartlinenum;
    }

    /**
     * Sets the value of the materiallistpartlinenum property.
     * 
     */
    public void setMATERIALLISTPARTLINENUM(long value) {
        this.materiallistpartlinenum = value;
    }

}
